@@ -3,6 +3,7 @@ package OpenFrame::Slot::ErrorText;
 use OpenFrame::Slot;
 use OpenFrame::AbstractRequest;
 use OpenFrame::AbstractResponse;
+use OpenFrame::Constants;
 
 use base qw ( OpenFrame::Slot );
 
@@ -11,21 +12,24 @@ sub what {
 }
 
 sub action {
+  my $class  = shift;
+  my $config = shift;
   my $response = OpenFrame::AbstractResponse->new();
-  $response->setMessage(
+  $response->message(
 			q{
 			  <html>
 			  <head>
 			    <title>Error</title>
 			  </head>
 			  <body>
-			    Hooray!
+			    <h1>Error</h1>
+                            <p>There was an error processing your request</p>
 			  </body>
 			  </html>
 			 }
 		       );
 
-  $response->setMessageCode( ofOK );
+  $response->code(ofOK);
   return $response;
 }
 
